==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
var TriangulationDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TriangulationDataSourceDescriptionMetadata, _super);
    function TriangulationDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TriangulationDataSourceDescriptionMetadata.b = function (a) {
        if (TriangulationDataSourceDescriptionMetadata.a == null) {
            TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
        }
        if (a.k(TriangulationDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.ab(TriangulationDataSourceDescriptionMetadata.a);
        AsyncCompletedEventArgsDescriptionMetadata.d(a);
    };
    TriangulationDataSourceDescriptionMetadata.c = function (a) {
        a.item("ImportCompletedRef", "EventRef::importCompleted");
    };
    TriangulationDataSourceDescriptionMetadata.d = function (a) {
        TriangulationDataSourceDescriptionMetadata.b(a);
        a.ad("TriangulationDataSource", function () { return new TriangulationDataSourceDescription(); });
        a.ac("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
    };
    TriangulationDataSourceDescriptionMetadata.$t = markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
}(Base));
export { TriangulationDataSourceDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/TriangulationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescriptionMetadata } from "./AsyncCompletedEventArgsDescriptionMetadata";
import { TriangulationDataSourceDescription } from "./TriangulationDataSourceDescription";
/**
 * @hidden
 */
var TriangulationDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TriangulationDataSourceDescriptionMetadata, _super);
    function TriangulationDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TriangulationDataSourceDescriptionMetadata.b = function (a) {
        if (TriangulationDataSourceDescriptionMetadata.a == null) {
            TriangulationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TriangulationDataSourceDescriptionMetadata.c(TriangulationDataSourceDescriptionMetadata.a);
        }
        if (a.k(TriangulationDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.ac(TriangulationDataSourceDescriptionMetadata.a);
        AsyncCompletedEventArgsDescriptionMetadata.d(a);
    };
    TriangulationDataSourceDescriptionMetadata.c = function (a) {
        a.item("ImportCompletedRef", "EventRef::importCompleted");
    };
    TriangulationDataSourceDescriptionMetadata.d = function (a) {
        TriangulationDataSourceDescriptionMetadata.b(a);
        a.ae("TriangulationDataSource", function () { return new TriangulationDataSourceDescription(); });
        a.ad("TriangulationDataSource", TriangulationDataSourceDescriptionMetadata.a);
    };
    TriangulationDataSourceDescriptionMetadata.$t = markType(TriangulationDataSourceDescriptionMetadata, 'TriangulationDataSourceDescriptionMetadata');
    TriangulationDataSourceDescriptionMetadata.a = null;
    return TriangulationDataSourceDescriptionMetadata;
}(Base));
export { TriangulationDataSourceDescriptionMetadata };
